@@ -1,28 +1,30 @@
 # -*- coding: utf-8 -*-
 
 import logging
+from copy import copy
+from json import dumps
+
 from colander import Boolean
 from colander import Float
 from colander import Integer
 from colander import MappingSchema
 from colander import SchemaNode
 from deform import Button
-from deform import ValidationFailure
-from copy import copy
 from deform import Form
+from deform import ValidationFailure
 from js.mediaelement import mediaelementandplayer
-from json import dumps
 from kotti.resources import Document
 from kotti.security import has_permission
-from kotti_media.resources import Audio
-from kotti_media.resources import Video
-from kotti_media.static import kotti_media_js
 from pyramid.i18n import TranslationStringFactory
-from pyramid.url import resource_url
 from pyramid.response import Response
+from pyramid.url import resource_url
 from pyramid.view import view_config
 from pyramid.view import view_defaults
 
+from kotti_media.resources import Audio
+from kotti_media.resources import Video
+from kotti_media.fanstatic import kotti_media_js
+
 _ = TranslationStringFactory('kotti_media')
 log = logging.getLogger(__name__)
 
@@ -221,8 +223,8 @@ class MediaFolderView(BaseView):
                  renderer="kotti_media:templates/media-folder-view.pt")
     def view(self):
 
-        media = [c for c in self.context.children \
-                 if (c.type in ("audio", "video", )) \
+        media = [c for c in self.context.children
+                 if (c.type in ("audio", "video", ))
                  and has_permission("view", self.context, self.request)]
         result = {
             "media": media,
@@ -234,7 +236,4 @@ class MediaFolderView(BaseView):
 
 def includeme(config):
 
-    import forms
-
-    forms.includeme(config)
-    config.scan("kotti_media")
+    config.scan(__name__)
